EditorConfig class

Configuration for the image editor appearance and behavior

Constructors

EditorConfig({Color primaryColor = Colors.blue, Color secondaryColor = Colors.grey, Color backgroundColor = Colors.white, Color textColor = Colors.black87, Color borderColor = Colors.grey, double maxHeight = 600.0, String? fontFamily, double titleFontSize = 18.0, double bodyFontSize = 14.0, double buttonFontSize = 16.0, double borderRadius = 8.0, EdgeInsets padding = const EdgeInsets.all(16.0), EdgeInsets margin = const EdgeInsets.all(8.0), bool showLoadingIndicators = true, String loadingText = 'Loading...', String saveButtonText = 'Save', String addOverlayText = 'Add Overlay Images', String galleryButtonText = 'Gallery', String cameraButtonText = 'Camera', String networkButtonText = 'Network'})
const

Properties

addOverlayText String
Custom add overlay text
final
backgroundColor Color
Background color of the editor
final
bodyFontSize double
Custom font size for body text
final
borderColor Color
Border color for the image container
final
borderRadius double
Border radius for containers
final
buttonFontSize double
Custom font size for buttons
final
cameraButtonText String
Custom camera button text
final
fontFamily String?
Custom font family for text elements
final
galleryButtonText String
Custom gallery button text
final
hashCode int
The hash code for this object.
no setterinherited
loadingText String
Custom loading text
final
margin EdgeInsets
Margin for UI elements
final
maxHeight double
Maximum height of the editor
final
networkButtonText String
Custom network button text
final
padding EdgeInsets
Padding for UI elements
final
primaryColor Color
Primary color for the UI elements
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveButtonText String
Custom save button text
final
secondaryColor Color
Secondary color for UI elements
final
showLoadingIndicators bool
Whether to show loading indicators
final
textColor Color
Text color for labels and buttons
final
titleFontSize double
Custom font size for titles
final

Methods

copyWith({Color? primaryColor, Color? secondaryColor, Color? backgroundColor, Color? textColor, Color? borderColor, double? maxHeight, String? fontFamily, double? titleFontSize, double? bodyFontSize, double? buttonFontSize, double? borderRadius, EdgeInsets? padding, EdgeInsets? margin, bool? showLoadingIndicators, String? loadingText, String? saveButtonText, String? addOverlayText, String? galleryButtonText, String? cameraButtonText, String? networkButtonText}) EditorConfig
Create a copy of this config with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

brandTheme({required Color primaryColor, required Color secondaryColor, String? fontFamily}) EditorConfig
Create a custom theme with brand colors
darkTheme() EditorConfig
Create a dark theme configuration
lightTheme() EditorConfig
Create a light theme configuration