OverlayImage class

Constructors

OverlayImage({required String id, required ImageSource source, required String imageUrl, required Offset position, required Size size, double rotation = 0.0, bool isLocal = false})
const
OverlayImage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
imageUrl String
final
isLocal bool
final
position Offset
final
rotation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
source ImageSource
final

Methods

copyWith({String? id, ImageSource? source, String? imageUrl, Offset? position, Size? size, double? rotation, bool? isLocal}) OverlayImage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited